"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VArray = void 0;
const rules_1 = require("../rules");
const rules_2 = require("../utils/rules");
const core_1 = require("./core");
class VArray extends core_1.VCore {
    constructor(comparer, err) {
        super();
        this.addTyping((0, rules_1.isArray)(err));
        this.addTyping((0, rules_2.makeRule)((value) => {
            const mapped = (value ?? []).reduce((acc, cur) => {
                const comp = comparer.parse(cur);
                acc[0].push(comp.value);
                acc[1].push(comp.valid);
                return acc;
            }, [[], []]);
            return (0, rules_1.isArrayOf)((_, i) => mapped[1][i], err)(mapped[0]);
        }));
    }
    has(length, err) {
        return this.addRule((0, rules_1.hasLengthOf)(length, err));
    }
    min(length, err) {
        return this.addRule((0, rules_1.hasMinOf)(length, err));
    }
    max(length, err) {
        return this.addRule((0, rules_1.hasMaxOf)(length, err));
    }
    set(keyFn = (v) => v) {
        return this.addSanitizer((val) => {
            const finalArr = [];
            const obj = {};
            val.forEach((v) => {
                const key = keyFn(v);
                if (obj[key])
                    return;
                obj[key] = true;
                finalArr.push(v);
            });
            return finalArr;
        });
    }
}
exports.VArray = VArray;
//# sourceMappingURL=arrays.js.map