"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VBase = void 0;
const rules_1 = require("../utils/rules");
class VBase {
    #force = undefined;
    #groups = [
        {
            transformer: ((v) => v),
            typings: [], rules: [], sanitizers: [],
            options: { original: false, required: true, nullable: false, default: undefined }
        }
    ];
    get forced() {
        return !!this.#force;
    }
    static createType(c) {
        return (...args) => new c(...args);
    }
    static createForcedType(c, conv) {
        return (...args) => new c(...args)._setForced(conv);
    }
    clone(base) {
        this.#force = base.#force;
        this.#groups = base.#groups;
        return this;
    }
    parse(input, ignoreRulesIfNotRequired = true) {
        let value = input;
        if (this.#force)
            value = this.#force(value);
        let res = { errors: [], valid: true, value, ignored: false };
        for (const group of this.#groups) {
            const val = this.#value(res.value, group.options);
            const typeCheck = (0, rules_1.check)(val, group.typings, { ignoreRulesIfNotRequired, ...group.options });
            if (!typeCheck.valid)
                return typeCheck;
            const sanitizedValue = typeCheck.ignored ? typeCheck.value : this.#sanitize(typeCheck.value, group.sanitizers);
            const v = (0, rules_1.check)(sanitizedValue, group.rules, { ignoreRulesIfNotRequired, ...group.options });
            if (!v.valid)
                return v;
            const retValue = group.options.original ? res.value : group.transformer(v.value);
            res = { ...v, valid: true, value: retValue };
        }
        return res;
    }
    addTyping(rule) {
        this.#groups.at(-1).typings.push(rule);
        return this;
    }
    addRule(rule) {
        this.#groups.at(-1).rules.push(rule);
        return this;
    }
    addSanitizer(sanitizer) {
        this.#groups.at(-1).sanitizers.push(sanitizer);
        return this;
    }
    _addTransform(transformer) {
        this.#groups.at(-1).transformer = transformer;
        this.#groups.push({
            transformer: (v) => v,
            typings: [], rules: [], sanitizers: [],
            options: {
                original: false,
                required: true,
                nullable: false,
                default: undefined
            }
        });
        return this;
    }
    _setOption(key, value) {
        if (this.#groups.at(-1)?.options)
            this.#groups.at(-1).options[key] = value;
        return this;
    }
    _setForced(conv) {
        this.#force = conv;
        return this;
    }
    #value(value, options) {
        if (value !== undefined)
            return value;
        const def = options.default;
        if (def !== undefined)
            return typeof def === 'function' ? def() : def;
        return undefined;
    }
    #sanitize(value, sanitizers) {
        return sanitizers.reduce((v, sanitizer) => sanitizer(v), value);
    }
}
exports.VBase = VBase;
//# sourceMappingURL=base.js.map