"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VDiscriminator = exports.VAnd = exports.VOr = void 0;
const functions_1 = require("../utils/functions");
const rules_1 = require("../utils/rules");
const core_1 = require("./core");
class VOr extends core_1.VCore {
    constructor(options, err = 'doesnt match any of the schema') {
        super();
        this.addTyping((0, rules_1.makeRule)((value) => {
            const val = value;
            if (options.length === 0)
                return (0, rules_1.isValid)(val);
            for (const opt of options) {
                const valid = opt.parse(val);
                if (valid.valid)
                    return valid;
            }
            return (0, rules_1.isInvalid)([err], val);
        }));
    }
}
exports.VOr = VOr;
class VAnd extends core_1.VCore {
    constructor(options, err) {
        super();
        this.addTyping((0, rules_1.makeRule)((value) => {
            let v = value;
            if (options.length === 0)
                return (0, rules_1.isValid)(v);
            for (const opt of options) {
                const valid = opt.parse(v);
                if (valid.valid)
                    v = valid.value;
                else
                    return (0, rules_1.isInvalid)(err ? [err] : valid.errors, v);
            }
            return (0, rules_1.isValid)(v);
        }));
    }
}
exports.VAnd = VAnd;
class VDiscriminator extends core_1.VCore {
    constructor(discriminator, schemas, err = 'doesnt match any of the schema') {
        super();
        this.addTyping((0, rules_1.makeRule)((value) => {
            const val = value;
            const accessor = (0, functions_1.wrapInTryCatch)(() => discriminator(val));
            if (!schemas[accessor])
                return (0, rules_1.isInvalid)([err], val);
            return schemas[accessor].parse(val);
        }));
    }
}
exports.VDiscriminator = VDiscriminator;
//# sourceMappingURL=junctions.js.map