"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VObject = void 0;
const rules_1 = require("../utils/rules");
const core_1 = require("./core");
class VObject extends core_1.VCore {
    constructor(schema, trim = true, err) {
        super();
        this.addTyping((0, rules_1.makeRule)((value) => {
            const val = structuredClone(value);
            const keys = new Set([...Object.keys(val ?? {}), ...Object.keys(schema)]);
            const errors = [];
            for (const key of keys) {
                if (!(key in schema)) {
                    if (trim) {
                        try {
                            delete val[key];
                        }
                        catch { }
                    }
                    continue;
                }
                const validity = schema[key].parse(val?.[key]);
                const errorStart = schema[key] instanceof VObject ? `${key}.` : `${key}: `;
                if (!validity.valid)
                    errors.push(...validity.errors.map((e) => errorStart + e));
                if (val && validity.valid)
                    val[key] = validity.value;
            }
            return errors.length > 0 ? (0, rules_1.isInvalid)(err ? [err] : errors, val) : (0, rules_1.isValid)(val);
        }));
    }
}
exports.VObject = VObject;
//# sourceMappingURL=objects.js.map