"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VRecord = exports.VMap = void 0;
const rules_1 = require("../rules");
const rules_2 = require("../utils/rules");
const core_1 = require("./core");
class VMap extends core_1.VCore {
    constructor(kCom, vCom, err) {
        super();
        this.addTyping((0, rules_1.isInstanceOf)(Map, err));
        this.addTyping((0, rules_2.makeRule)((value) => {
            const val = structuredClone(value);
            for (const k of val?.keys() ?? []) {
                const v = val?.get(k);
                const kValid = kCom.parse(k);
                const vValid = vCom.parse(v);
                if (!kValid.valid)
                    return (0, rules_2.isInvalid)(err ? [err] : [`contains an invalid key ${String(k)}`], val);
                if (!vValid.valid)
                    return (0, rules_2.isInvalid)(err ? [err] : [`contains an invalid value for key ${String(k)}`], val);
                if (k !== kValid.value)
                    val?.delete(k);
                val?.set(kValid.value, vValid.value);
            }
            return (0, rules_2.isValid)(val);
        }));
    }
}
exports.VMap = VMap;
class VRecord extends core_1.VCore {
    constructor(vCom, err) {
        super();
        this.addTyping((0, rules_2.makeRule)((value) => {
            if (Array.isArray(value))
                return (0, rules_2.isInvalid)(err ? [err] : ['is not an object'], value);
            const val = structuredClone(value);
            for (const [k, v] of Object.entries(val ?? {})) {
                const validity = vCom.parse(v);
                err = err ?? `contains an invalid value for key ${k}`;
                if (!validity.valid)
                    return (0, rules_2.isInvalid)([err], val);
                if (value)
                    value[k] = validity.value;
            }
            return (0, rules_2.isValid)(val);
        }));
    }
}
exports.VRecord = VRecord;
//# sourceMappingURL=records.js.map