"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VString = void 0;
const rules_1 = require("../rules");
const functions_1 = require("../utils/functions");
const core_1 = require("./core");
class VString extends core_1.VCore {
    constructor(err) {
        super();
        this.addTyping((0, rules_1.isString)(err));
    }
    has(length, stripHTML = false, err) {
        return this.addRule((0, rules_1.isLengthOf)(length, stripHTML, err));
    }
    min(length, stripHTML = false, err) {
        return this.addRule((0, rules_1.isMinOf)(length, stripHTML, err));
    }
    max(length, stripHTML = false, err) {
        return this.addRule((0, rules_1.isMaxOf)(length, stripHTML, err));
    }
    email(err) {
        return this.addRule((0, rules_1.isEmail)(err));
    }
    url(err) {
        return this.addRule((0, rules_1.isUrl)(err));
    }
    trim() {
        return this.addSanitizer((val) => val.trim());
    }
    lower() {
        return this.addSanitizer((val) => val.toLowerCase());
    }
    upper() {
        return this.addSanitizer((val) => val.toUpperCase());
    }
    capitalize() {
        return this.addSanitizer((val) => (0, functions_1.capitalize)(val));
    }
    stripHTML() {
        return this.addSanitizer((val) => (0, functions_1.stripHTML)(val));
    }
    slice(length) {
        return this.addSanitizer((val) => (0, functions_1.trimToLength)(val, length));
    }
}
exports.VString = VString;
//# sourceMappingURL=strings.js.map