"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isArrayOf = exports.hasMaxOf = exports.hasMinOf = exports.hasLengthOf = exports.isArray = void 0;
const rules_1 = require("../utils/rules");
const isArray = (error = 'is not an array') => (0, rules_1.makeRule)((value) => {
    if (Array.isArray(value))
        return (0, rules_1.isValid)(value);
    return (0, rules_1.isInvalid)([error], value);
});
exports.isArray = isArray;
const hasLengthOf = (length, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isArray)()(value);
    if (!v.valid)
        return v;
    error = error ?? `must contain ${length} items`;
    const val = value;
    if (val.length === length)
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.hasLengthOf = hasLengthOf;
const hasMinOf = (length, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isArray)()(value);
    if (!v.valid)
        return v;
    error = error ?? `must contain ${length} or more items`;
    const val = value;
    if (val.length >= length)
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.hasMinOf = hasMinOf;
const hasMaxOf = (length, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isArray)()(value);
    if (!v.valid)
        return v;
    error = error ?? `must contain ${length} or less items`;
    const val = value;
    if (val.length <= length)
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.hasMaxOf = hasMaxOf;
const isArrayOf = (comparer, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isArray)()(value);
    if (!v.valid)
        return v;
    const val = value;
    const invIndex = val.findIndex((elem, i) => !comparer(elem, i));
    const invalid = invIndex !== -1;
    error = error ?? `contains invalid values at index ${invIndex}`;
    return invalid ? (0, rules_1.isInvalid)([error], val) : (0, rules_1.isValid)(val);
});
exports.isArrayOf = isArrayOf;
//# sourceMappingURL=arrays.js.map