"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.arrayNotContains = exports.arrayContains = exports.isNotEqualTo = exports.isEqualTo = void 0;
const differ_1 = require("../utils/differ");
const rules_1 = require("../utils/rules");
const isEqualTo = (compare, comparer = differ_1.Differ.equal, error) => (0, rules_1.makeRule)((value) => {
    error = error ?? `is not equal to ${compare}`;
    const val = value;
    if (value === compare)
        return (0, rules_1.isValid)(val);
    if (comparer(val, compare))
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.isEqualTo = isEqualTo;
const isNotEqualTo = (compare, comparer = differ_1.Differ.equal, error) => (0, rules_1.makeRule)((value) => {
    error = error ?? `is equal to ${compare}`;
    const val = value;
    if (value !== compare)
        return (0, rules_1.isValid)(val);
    if (!comparer(val, compare))
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.isNotEqualTo = isNotEqualTo;
const arrayContains = (array, comparer = differ_1.Differ.equal, error) => (0, rules_1.makeRule)((value) => {
    error = error ?? `is not in the list: [${array.join(',')}]`;
    const val = value;
    if (array.find((x) => comparer(val, x)))
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.arrayContains = arrayContains;
const arrayNotContains = (array, comparer = differ_1.Differ.equal, error) => (0, rules_1.makeRule)((value) => {
    error = error ?? `is in the list: [${array.join(',')}]`;
    const val = value;
    if (array.find((x) => comparer(val, x)))
        return (0, rules_1.isInvalid)([error], val);
    return (0, rules_1.isValid)(val);
});
exports.arrayNotContains = arrayNotContains;
//# sourceMappingURL=equality.js.map