"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isLessThanOrEqualTo = exports.isLessThan = exports.isMoreThanOrEqualTo = exports.isMoreThan = exports.isInt = exports.isNumber = void 0;
const rules_1 = require("../utils/rules");
const isNumber = (error = 'is not a number') => (0, rules_1.makeRule)((value) => {
    if (typeof value === 'number' && !isNaN(value))
        return (0, rules_1.isValid)(value);
    return (0, rules_1.isInvalid)([error], value);
});
exports.isNumber = isNumber;
const isInt = (error = 'is not an integer') => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isNumber)()(value);
    if (!v.valid)
        return v;
    const val = value;
    if (val === parseInt(val))
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.isInt = isInt;
const isMoreThan = (compare, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isNumber)()(value);
    if (!v.valid)
        return v;
    error = error ?? `must be greater than ${compare}`;
    const val = value;
    if (val > compare)
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.isMoreThan = isMoreThan;
const isMoreThanOrEqualTo = (compare, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isNumber)()(value);
    if (!v.valid)
        return v;
    error = error ?? `must be greater than or equal to ${compare}`;
    const val = value;
    if (val >= compare)
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.isMoreThanOrEqualTo = isMoreThanOrEqualTo;
const isLessThan = (compare, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isNumber)()(value);
    if (!v.valid)
        return v;
    error = error ?? `must be less than ${compare}`;
    const val = value;
    if (val < compare)
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.isLessThan = isLessThan;
const isLessThanOrEqualTo = (compare, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isNumber)()(value);
    if (!v.valid)
        return v;
    error = error ?? `must be less than or equal to ${compare}`;
    const val = value;
    if (val <= compare)
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.isLessThanOrEqualTo = isLessThanOrEqualTo;
//# sourceMappingURL=numbers.js.map