"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isUrl = exports.isEmail = exports.isMaxOf = exports.isMinOf = exports.isLengthOf = exports.isString = void 0;
const functions_1 = require("../utils/functions");
const regexes_1 = require("../utils/regexes");
const rules_1 = require("../utils/rules");
const isString = (error = 'is not a string') => (0, rules_1.makeRule)((value) => {
    if (value === null || value === undefined)
        return (0, rules_1.isInvalid)([error], value);
    if (!value.constructor)
        return (0, rules_1.isInvalid)([error], value);
    if (value.constructor.name !== 'String')
        return (0, rules_1.isInvalid)([error], value);
    return (0, rules_1.isValid)(value);
});
exports.isString = isString;
const isLengthOf = (length, stripHTMLTags = false, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isString)()(value);
    if (!v.valid)
        return v;
    const val = value;
    error = error ?? `must contain ${length} characters`;
    if ((stripHTMLTags ? (0, functions_1.stripHTML)(val) : val).trim().length === length)
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.isLengthOf = isLengthOf;
const isMinOf = (length, stripHTMLTags = false, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isString)()(value);
    if (!v.valid)
        return v;
    const val = value;
    error = error ?? `must contain ${length} or more characters`;
    if ((stripHTMLTags ? (0, functions_1.stripHTML)(val) : val).trim().length >= length)
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.isMinOf = isMinOf;
const isMaxOf = (length, stripHTMLTags = false, error) => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isString)()(value);
    if (!v.valid)
        return v;
    const val = value;
    error = error ?? `must contain ${length} or less characters`;
    if ((stripHTMLTags ? (0, functions_1.stripHTML)(val) : val).trim().length <= length)
        return (0, rules_1.isValid)(val);
    return (0, rules_1.isInvalid)([error], val);
});
exports.isMaxOf = isMaxOf;
const isEmail = (error = 'is not a valid email') => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isString)()(value);
    if (!v.valid)
        return v;
    const val = value;
    return regexes_1.emailRegex.test(val) ? (0, rules_1.isValid)(val) : (0, rules_1.isInvalid)([error], val);
});
exports.isEmail = isEmail;
const isUrl = (error = 'is not a valid url') => (0, rules_1.makeRule)((value) => {
    const v = (0, exports.isString)()(value);
    if (!v.valid)
        return v;
    const val = value;
    return (0, regexes_1.urlRegex)().test(val) ? (0, rules_1.isValid)(val) : (0, rules_1.isInvalid)([error], val);
});
exports.isUrl = isUrl;
//# sourceMappingURL=strings.js.map