"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.compareTwoStrings = exports.wrapInTryCatch = exports.chunkArray = exports.shuffleArray = exports.getRandomSample = exports.getPercentage = exports.divideByZero = exports.addToArray = exports.getAlphabet = exports.groupBy = exports.getRandomValue = exports.pluralize = exports.formatNumber = exports.extractUrls = exports.trimToLength = exports.stripHTML = exports.capitalize = void 0;
const rules_1 = require("../../rules");
const regexes_1 = require("../regexes");
const normalize_1 = require("./urls/normalize");
const capitalize = (text) => {
    if (text === null || text === undefined)
        return text;
    text = text.toString();
    const c = (v) => (v[0]?.toUpperCase() ?? '') + v.slice(1);
    return text.trim().split(' ').map(c).join(' ');
};
exports.capitalize = capitalize;
const stripHTML = (html) => {
    if (html === null || html === undefined)
        return html;
    return html?.toString()?.trim().replace(/<[^>]+>/g, '') ?? '';
};
exports.stripHTML = stripHTML;
const trimToLength = (body, length) => {
    if (body === null || body === undefined)
        return body;
    body = body.toString();
    if (body.length <= length)
        return body;
    const indexOfSpace = body.indexOf(' ', length);
    const indexToTrim = indexOfSpace === -1 ? length : indexOfSpace;
    return `${body.slice(0, indexToTrim)}...`;
};
exports.trimToLength = trimToLength;
const extractUrls = (text) => {
    const urls = text.match((0, regexes_1.urlRegex)()) || [];
    return urls.filter(((url, index) => urls.indexOf(url) === index)).map((url) => {
        url = url.trim();
        return {
            original: url,
            normalized: (0, normalize_1.normalizeUrl)(url.replace(/\.+$/, ''))
        };
    });
};
exports.extractUrls = extractUrls;
const formatNumber = (num, dp) => Intl
    .NumberFormat('en', { notation: 'compact', ...(dp ? { maximumFractionDigits: dp } : {}) })
    .format((0, rules_1.isNumber)()(num).valid ? num : 0);
exports.formatNumber = formatNumber;
const pluralize = (count, singular, plural) => Math.round(count) === 1 ? singular : plural;
exports.pluralize = pluralize;
const getRandomValue = () => Date.now() + Math.random().toString(36);
exports.getRandomValue = getRandomValue;
const groupBy = (array, func) => {
    return array.reduce((acc, cur) => {
        const key = func(cur);
        const index = acc.findIndex((a) => a.key === key);
        if (index === -1)
            acc.push({ key, values: [cur] });
        else
            acc[index].values.push(cur);
        return acc;
    }, []);
};
exports.groupBy = groupBy;
const getAlphabet = (num) => 'abcdefghijklmnopqrstuv'.split('')[num] ?? 'a';
exports.getAlphabet = getAlphabet;
const addToArray = (array, item, getKey, getComparer, asc = false) => {
    const existingIndex = array.findIndex((el) => getKey(el) === getKey(item));
    const index = array.findIndex((el) => asc ? getComparer(el) >= getComparer(item) : getComparer(el) <= getComparer(item));
    if (existingIndex !== -1 && existingIndex === index) {
        array.splice(existingIndex, 1, item);
        return array;
    }
    if (existingIndex !== -1 && existingIndex !== index)
        array.splice(existingIndex, 1);
    if (index !== -1)
        array.splice(index, 0, item);
    else if (array.length === 0)
        array.push(item);
    else {
        const existingIsGreater = getComparer(array[0]) >= getComparer(item);
        if (existingIsGreater)
            asc ? array.unshift(item) : array.push(item);
        else
            asc ? array.push(item) : array.unshift(item);
    }
    return array;
};
exports.addToArray = addToArray;
const divideByZero = (num, den) => den === 0 ? 0 : num / den;
exports.divideByZero = divideByZero;
const getPercentage = (num, den) => 100 * ((0, exports.divideByZero)(num, den) > 1 ? 1 : (0, exports.divideByZero)(num, den));
exports.getPercentage = getPercentage;
const getRandomSample = (population, n) => {
    const indexes = [];
    const indexesObject = {};
    while (indexes.length < n && indexes.length < population.length) {
        const random = Math.floor(Math.random() * population.length);
        if (random in indexesObject)
            continue;
        indexesObject[random] = true;
        indexes.push(random);
    }
    return indexes.map((idx) => population[idx]);
};
exports.getRandomSample = getRandomSample;
const shuffleArray = (array) => [...array].sort(() => Math.random() - 0.5);
exports.shuffleArray = shuffleArray;
const chunkArray = (arr, size) => {
    const chunks = [];
    for (let i = 0; i < arr.length; i += size)
        chunks.push(arr.slice(i, i + size));
    return chunks;
};
exports.chunkArray = chunkArray;
const wrapInTryCatch = (fn, defaultValue) => {
    try {
        return fn();
    }
    catch {
        return defaultValue;
    }
};
exports.wrapInTryCatch = wrapInTryCatch;
const compareTwoStrings = (first, second) => {
    first = first.replace(/\s+/g, '');
    second = second.replace(/\s+/g, '');
    if (first === second)
        return 1;
    if (first.length < 2 || second.length < 2)
        return 0;
    const firstBigrams = new Map();
    for (let i = 0; i < first.length - 1; i++) {
        const bigram = first.substring(i, i + 2);
        const count = firstBigrams.has(bigram)
            ? firstBigrams.get(bigram) + 1
            : 1;
        firstBigrams.set(bigram, count);
    }
    ;
    let intersectionSize = 0;
    for (let i = 0; i < second.length - 1; i++) {
        const bigram = second.substring(i, i + 2);
        const count = firstBigrams.has(bigram)
            ? firstBigrams.get(bigram)
            : 0;
        if (count > 0) {
            firstBigrams.set(bigram, count - 1);
            intersectionSize++;
        }
    }
    return (2.0 * intersectionSize) / (first.length + second.length - 2);
};
exports.compareTwoStrings = compareTwoStrings;
//# sourceMappingURL=index.js.map