export type Rule<T> = (value: unknown) => ReturnType<typeof isValid<T>> | ReturnType<typeof isInvalid<T>>;
export type Sanitizer<T> = (value: T) => T;
export type Transformer<I, O> = (value: I) => O;
export type Options = {
    required: boolean | (() => boolean);
    nullable: boolean;
    ignoreRulesIfNotRequired?: boolean;
};
export declare const isValid: <T>(value: T, ignored?: boolean) => {
    valid: true;
    errors: string[];
    value: T;
    ignored: boolean;
};
export declare const isInvalid: <T>(errors: string[], value: T) => {
    valid: false;
    errors: string[];
    value: unknown;
    ignored: boolean;
};
export declare const makeRule: <T>(func: Rule<T>) => Rule<T>;
export declare const makeSanitizer: <T>(func: Sanitizer<T>) => (val: T) => T;
export declare const check: <T>(value: T, rules: Rule<T>[], options?: Partial<Options>) => ReturnType<Rule<T>>;
