"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.check = exports.makeSanitizer = exports.makeRule = exports.isInvalid = exports.isValid = void 0;
const isValid = (value, ignored = false) => ({ valid: true, errors: [], value, ignored });
exports.isValid = isValid;
const isInvalid = (errors, value) => ({ valid: false, errors, value, ignored: false });
exports.isInvalid = isInvalid;
const makeRule = (func) => (val) => func(val);
exports.makeRule = makeRule;
const makeSanitizer = (func) => (val) => func(val);
exports.makeSanitizer = makeSanitizer;
const check = (value, rules, options) => {
    const allOptions = { required: true, nullable: false, ignoreRulesIfNotRequired: false, ...(options ?? {}) };
    if (rules.length === 0)
        return { valid: true, errors: [], value, ignored: false };
    const presence = typeof allOptions.required === 'function' ? allOptions.required() : allOptions.required;
    if (!presence && (value === undefined || allOptions.ignoreRulesIfNotRequired))
        return { valid: true, errors: [], value, ignored: true };
    if (value === null && allOptions.nullable)
        return { valid: true, errors: [], value, ignored: true };
    let res = { errors: [], valid: true, value };
    for (const rule of rules) {
        res = rule(res.value);
        if (!res.valid)
            break;
    }
    return { ...res, errors: [...new Set(res.errors)], ignored: false };
};
exports.check = check;
//# sourceMappingURL=rules.js.map